package dev.svitan.routes

import dev.svitan.schemas.AuthService
import dev.svitan.schemas.NewAuthDTO
import io.ktor.http.HttpStatusCode
import io.ktor.server.application.Application
import io.ktor.server.auth.authentication
import io.ktor.server.plugins.NotFoundException
import io.ktor.server.request.receive
import io.ktor.server.response.respond
import io.ktor.server.routing.*
import java.util.UUID

fun Application.routeAuth() {
    routing {
        authentication {
            get("/auth") {
                call.respond(AuthService.readAll())
            }

            put("/auth") {
                val auth = call.receive<NewAuthDTO>()
                call.respond(HttpStatusCode.Created, AuthService.create(auth))
            }

            get("/auth/{id}") {
                val idRaw = call.parameters["id"] ?: throw IllegalArgumentException("Invalid id")
                val id = UUID.fromString(idRaw)
                val auth = AuthService.read(id) ?: throw NotFoundException()
                call.respond(auth)
            }

            delete("/auth/{id}") {
                val idRaw = call.parameters["id"] ?: throw IllegalArgumentException("Invalid id")
                val id = UUID.fromString(idRaw)
                AuthService.delete(id)
                call.respond(HttpStatusCode.NoContent)
            }
        }
    }
}
